//-----------------------------------------------------
//导入
//________________________________________________________________

import { world, system } from '@minecraft/server';
import { score } from 'score.js';
import { fightSkill } from 'enhancement/dna.js'
import { sptwNoSkill } from 'stands/sptw.js';
import { kqNoSkill } from 'stands/kq.js';
import { e3NoSkill } from 'stands/e3.js';
import { cdNoSkill } from 'stands/cd.js';
import { cpNoSkill, summonPlayer } from 'stands/cp.js';
import { hwNoSkill } from 'stands/hw.js';
import { bcNoSkill } from 'stands/bc.js';
import { twNoSkill } from 'stands/tw.js';
import 'base/summon.js'
import * as summon from 'base/summon.js';
import * as kq from 'stands/kq.js';
import * as tw from 'stands/tw.js';

//-----------------------------------------------------
//导出
//________________________________________________________________

export { defendData };

//-----------------------------------------------------
//变量
//________________________________________________________________

let defendData = {
    "playerName": {
        "isDefend": true,
        "cd": 0
    }
};

const can_defend_stand = ["1", "2", "3", "4", "6", "9"]
const no_skill = [sptwNoSkill, kqNoSkill, e3NoSkill, cdNoSkill, cpNoSkill, twNoSkill]
const liti_stand = ["6"]

//-----------------------------------------------------
//重要
//________________________________________________________________

export function playerDefend(player) {
    if (!defendData[player.name]) {
        defendData[player.name] = {
            "isDefend": false,
            "cd": 0
        }
    }
    if (defendData[player.name]["cd"] > 0) {
        defendData[player.name]["cd"] = defendData[player.name]["cd"]-1
    }
    if (defendData[player.name]["cd"] > 0) {
        defendData[player.name]["cd"] = defendData[player.name]["cd"]-1
    }
    if (can_defend_stand.indexOf(`${score(player, "stand_type_id")}`) != -1) {
        player.runCommand(`scoreboard players set @s stand_skill_cd_1 ${defendData[player.name]["cd"]}`)
    }
    if (can_defend_stand.indexOf(`${score(player, "stand_type_id")}`) != -1 && player.selectedSlotIndex == 0 && player.isSneaking && !defendData[player.name]["isDefend"] && score(player, "stand_summon") != 0 && defendData[player.name]["cd"] == 0 && no_skill[can_defend_stand.indexOf(`${score(player, "stand_type_id")}`)](player) && summon.sneakTimeData[player.name]["cd"] == 0) {
        defendData[player.name]["isDefend"] = true;
        defendData[player.name]["cd"] = 40;
        player.runCommand("scoreboard players set @s stand_fpp_invisibility 0")
        if (liti_stand.indexOf(`${score(player, "stand_type_id")}`) == -1) {
            player.runCommand("playanimation @s animation.stand.defend_start")
        } else {
            player.runCommand("playanimation @s animation.player.shield_block_main_hand move 1")
        }
        const stand_type_id = score(player, "stand_type_id")
        system.runTimeout(() => {
            let defend = system.runInterval(() => {
                if (liti_stand.indexOf(`${score(player, "stand_type_id")}`) == -1) {
                    player.runCommand("playanimation @s animation.stand.defend")
                } else {
                    player.runCommand("playanimation @s animation.player.shield_block_main_hand move 1")
                }
                player.runCommand("scoreboard players set @s stand_fpp_invisibility 0")
                player.runCommand("effect @s resistance 1 0 true")
                if (!player.isSneaking || score(player, "stand_type_id") != stand_type_id || player.selectedSlotIndex != 0) {
                    system.clearRun(defend)
                    defendData[player.name]["isDefend"] = false;
                }
            })
        }, 4)
    }
}

//-----------------------------------------------------
//防反
//________________________________________________________________

world.afterEvents.entityHurt.subscribe(event => {
    try {
        const player = event.hurtEntity;
        const entity = event.damageSource.damagingEntity;
        const cause = event.damageSource.cause;
        const damage = event.damage;
                
        let defend_time = 35;
        const fs = new fightSkill(player)
        if (fs.getFightSkill()["fs"].indexOf("坚盾") != -1) {
            defend_time = 32;
        }
        
        if (player.typeId == "minecraft:player" && (cause == "entityAttack" || cause == "ramAttack" ) && player.getComponent("minecraft:health").currentValue != 0 && defendData[player.name]["cd"] >= defend_time && defendData[player.name]["isDefend"]) {
            defendData[player.name]["cd"] = 0;
            player.getComponent("minecraft:health").setCurrentValue(player.getComponent("minecraft:health").currentValue+damage)
            player.runCommand("playsound item.shield.block @a ~~~ 100 1 0")
            player.runCommand("effect @s strength 5 0 true")
            player.addTag("defend:true")
            entity.runCommand(`damage @s ${parseInt(damage)} entity_attack entity @a[name="${player.name}"]`)
            if (score(player, "stand_type_id") == 2) {  
                player.addTag("combo_c")
                kq.comboBoomId[player.name] = entity.id
            }
            if (score(player, "stand_type_id") == 9) {  
                player.runCommand(`effect @e[tag="id${entity.id}"] blindness 1 1 true`)
                player.runCommand(`effect @e[tag="id${entity.id}"] slowness 1 2 true`)
                player.runCommand(`execute as @e[tag="id${entity.id}"] at @s run playsound tp @a ~~~ 100 1 0`)
                player.runCommand(`execute as @e[tag="id${entity.id}"] at @s if block ^^^-1 air if  block ^^^-1 air run tp @e[tag="id${player.id}"] ^^^-1 facing @s `)
                player.runCommand(`execute as @e[tag="id${entity.id}"] at @s unless block ^^^-1 air unless block ^^^-1 air run tp @e[tag="id${player.id}"] ^^^-0.1 facing @s `)
                player.runCommand(`execute as @e[tag="id${entity.id}"] at @s unless block ^^^-1 air unless block ^^^-1 air run tp ^^1^1`)
            }
            if (score(player, "stand_type_id") == 4) {
                let i = 0;
                let angry = system.runInterval(() => {
                    i += 1
                    player.runCommand("scoreboard players add @s[scores={angry=..99}] angry 1")
                    if (i > 9) {
                        system.clearRun(angry)
                    }
                })
            }
            system.runTimeout(() => {
                player.removeTag("defend:true")
            }, 20)
            system.runTimeout(() => {
                player.removeTag("combo_c")
            }, 40)
        }
    } catch (error) {
        // world.sendMessage(`${error}`)
    }
})

world.afterEvents.entityHurt.subscribe(event => {
    try {
        const player = event.hurtEntity;
        const cause = event.damageSource.cause;
        const damage = event.damage;
        
        let defend_time = 32;
        const fs = new fightSkill(player)
        if (fs.getFightSkill()["fs"].indexOf("坚盾") != -1) {
            defend_time = 28;
        }
                
        if (player.typeId == "minecraft:player" && cause == "projectile" && player.getComponent("minecraft:health").currentValue != 0 && defendData[player.name]["cd"] >= defend_time && defendData[player.name]["isDefend"]) {
            defendData[player.name]["cd"] = 0;
            player.getComponent("minecraft:health").setCurrentValue(player.getComponent("minecraft:health").currentValue+damage)
            player.runCommand("playsound item.shield.block @a ~~~ 100 1 0")
            player.runCommand("effect @s strength 5 0 true")
            player.addTag("defend:true")
            system.runTimeout(() => {
                player.removeTag("defend:true")
            }, 40)
        }
    } catch (error) {
        // world.sendMessage(`${error}`)
    }
})

world.afterEvents.projectileHitEntity.subscribe(event => {
    try {
        const player = event.getEntityHit().entity;
        const p = event.projectile;
        const v = event.hitVector;
        const l = event.location;
        const d = event.dimension;
                
        let defend_time = 30;
        const fs = new fightSkill(player)
        if (fs.getFightSkill()["fs"].indexOf("坚盾") != -1) {
            defend_time = 25;
        }
         
        if (player.typeId == "minecraft:player" && player.getComponent("minecraft:health").currentValue != 0 && defendData[player.name]["isDefend"]) {
            player.runCommand("playsound item.shield.block @a ~~~ 100 1 0")
            const bl = {
                x: l.x-0.1,
                y: l.y+0.25,
                z: l.z
            }
            const bp = d.spawnEntity(p.typeId, bl)
            if (score(player, "stand_type_id") == 2) {  
                kq.comboBoomId[player.name] = bp.id
                player.addTag("combo_c2")
                system.runTimeout(() => {
                    player.removeTag("combo_c2")
                }, 40)
            }
            let bv;
            if (defendData[player.name]["cd"] >= defend_time) {
                bv = {
                    x: -v.x,
                    y: -v.y,
                    z: -v.z
                }
            } else {
                 bv = {
                    x: -v.x*0.8,
                    y: -v.y*0.8,
                    z: -v.z*0.8
                }
            }
            bp.applyImpulse(bv)
        }
    } catch (error) {
        // world.sendMessage(`${error}`)
    }
})