//-----------------------------------------------------
//导入
//________________________________________________________________

import { world, system } from '@minecraft/server';
import { score } from 'score.js';
import { sptwNoSkill } from 'stands/sptw.js';
import { kqNoSkill } from 'stands/kq.js';
import { e3NoSkill } from 'stands/e3.js';
import { cdNoSkill } from 'stands/cd.js';
import { cpNoSkill, summonPlayer } from 'stands/cp.js';
import { hwNoSkill } from 'stands/hw.js';
import { bcNoSkill } from 'stands/bc.js';
import { twNoSkill } from 'stands/tw.js';

//-----------------------------------------------------
//导出
//________________________________________________________________

export { sneakTimeData };

//-----------------------------------------------------
//变量
//________________________________________________________________

let sneakTimeData = {
    "playerName": {
        "time": 0,
        "isSneaking": 0,
        "cd": 0
    }
};

//-----------------------------------------------------
//重要
//________________________________________________________________

export function playerSneaking(player) {
    if (sneakTimeData[player.name] != undefined) {
        let sneaking = player.isSneaking ? 1 : 0
        if (sneakTimeData[player.name]["time"] >= 1) {
            sneakTimeData[player.name]["time"] -= 1
        }
        if (sneakTimeData[player.name]["cd"] >= 1) {
            sneakTimeData[player.name]["cd"] -= 1
        }
        if (sneakTimeData[player.name]["isSneaking"] != sneaking) {
            sneakTimeData[player.name]["isSneaking"] = sneaking
            sneakTimeData[player.name]["time"] += 5
            if (sneakTimeData[player.name]["time"] >= 10) {
                sneakTimeData[player.name]["time"] = 10
                if (sneakTimeData[player.name]["cd"] == 0) {
                    if (score(player, "stand_type_id") > 0) {
                        standSummon(player)
                        //替身,启动！
                    }
                    sneakTimeData[player.name]["cd"] = 10
                }
            }
        }
    } else {
        sneakTimeData[player.name] = {
            "time": 0,
            "isSneaking": 0,
            "cd": 0
        }
    }
}

//-----------------------------------------------------
//函数
//________________________________________________________________

function standSummon(player) {
    let stand_type_id = score(player, "stand_type_id")
    let stand_summon = score(player, "stand_summon") > 0 ? true : false
    let cd1 = score(player, "stand_skill_cd_1")
    let cd2 = score(player, "stand_skill_cd_2")
    let cd3 = score(player, "stand_skill_cd_3")
    let cd4 = score(player, "stand_skill_cd_4")
    let cd5 = score(player, "stand_skill_cd_5")
    switch (stand_type_id) {
        case 1:
            if (sptwNoSkill(player)) {
                standSummonModule(player, {
                    show: "animation.stand.sptw.show",
                    end: "animation.stand.sptw.end",
                    sound: "sptw",
                    summon: "summon"
                })
            };
            break;
        case 2:
            if (kqNoSkill(player)) {
                standSummonModule(player, {
                    show: "animation.stand.kq.show",
                    end: "animation.stand.kq.end",
                    sound: "kq",
                    summon: "summon"
                })
            };
            break;
        case 3:
            if (e3NoSkill(player)) {
                standSummonModule(player, {
                    show: "animation.stand.e3.show",
                    end: "animation.stand.e3.end",
                    sound: "e3",
                    summon: "summon"
                })
            };
            break;
        case 4:
            if (cdNoSkill(player)) {
                standSummonModule(player, {
                    show: "animation.stand.cd.show",
                    end: "animation.stand.cd.end",
                    sound: "cd",
                    summon: "summon"
                })
            };
            break;
        case 5:
            if (!player.hasTag("paper")) {
                standSummonModule(player, {
                    show: "animation.stand.e.show",
                    end: "animation.stand.e.end",
                    sound: "?",
                    summon: "summon"
                })
            };
            break;
        case 6:
            if (cpNoSkill(player)) {
                standSummonModule(player, {
                    show: "animation.stand.cp.show?",
                    end: "animation.stand.cp.end?",
                    sound: "?",
                    summon: "summon"
                })
            };
            break;
        case 7:
            if (hwNoSkill(player)) {
                standSummonModule(player, {
                    show: "animation.stand.hw.show",
                    end: "animation.stand.hw.end",
                    sound: "hw",
                    summon: "summon"
                })
            }
            break;
        case 8:
            if (bcNoSkill(player)) {
                standSummonModule(player, {
                    show: "animation.stand.bc.show",
                    end: "animation.stand.bc.end",
                    sound: "?", 
                    summon: "summon"
                })
            }
            break;
        case 9:
            if (twNoSkill(player)) {
                standSummonModule(player, {
                    show: "animation.stand.tw.show",
                    end: "animation.stand.tw.end",
                    sound: "summon_tw", 
                    summon: "?"
                })
            }
            break;
    }
};



function standSummonModule(player, animation) {
    let stand_summon = score(player, "stand_summon") > 0 ? true : false
    if (!stand_summon) {
        player.runCommand("playanimation @s " + animation.show)
        player.runCommand("scoreboard players set @s stand_summon 1")
        player.runCommand("scoreboard players set @s stand_invisibility 0")
        player.runCommand("scoreboard players set @s stand_fpp_invisibility 0")
        player.runCommand(`playsound ${animation.summon} @a[r=5]`)
        player.runCommand("playsound " + animation.sound + " @a[r=5]")
        player.triggerEvent("sync:stand_fpp_invisibility_show_true")
        system.runTimeout(() => {
            player.runCommand("scoreboard players set @s stand_invisibility 1")
            player.runCommand("scoreboard players set @s stand_fpp_invisibility 1")
            player.triggerEvent("sync:stand_fpp_invisibility_show_false")
        }, 5)
        if (score(player, "stand_type_id") != 6) return;
        summonPlayer(player)
    } else {
        player.runCommand("playanimation @s " + animation.end)
        player.runCommand("scoreboard players set @s stand_invisibility 0")
        player.runCommand("scoreboard players set @s stand_fpp_invisibility 0")
        player.triggerEvent("sync:stand_fpp_invisibility_show_true")
        player.runCommand("playsound back @a[r=5]")
        system.runTimeout(() => {
            player.runCommand("scoreboard players set @s stand_summon 0")
        }, 3.2)
        if (score(player, "stand_type_id") != 6) return;
        player.runCommand(`tp @s @e[c=1,name="${player.name}",type=stand:players]`)
        player.runCommand(`tp @e[c=1,name="${player.name}",type=stand:players] 1145141 -500 0`)
    }
};