//-----------------------------------------------------
//导入
//________________________________________________________________

import { ItemStack, world, system } from '@minecraft/server';
import { ActionFormData, MessageFormData, ModalFormData } from '@minecraft/server-ui';
import { score, set } from 'score.js';

//-----------------------------------------------------
//事件
//________________________________________________________________

world.afterEvents.itemUse.subscribe(event => {
    const item = event.itemStack;
    const player = event.source;
    if (item.typeId == "stand:gb") {
        mainGb(player)
    }
});

//-----------------------------------------------------
//菜单
//________________________________________________________________

export function mainGb(player) {
    const points = {
        strong: romeN(score(player, "strong")),
        healthy: romeN(score(player, "healthy")),
        speed: romeN(score(player, "speed")),
        clever: romeN(score(player, "clever")),
        life_level: romeN(score(player, "life_level"))
    }
    
    const requires = {
        strong: parseInt(score(player, "strong")**2+600),
        speed: parseInt(score(player, "speed")**2+400),
        clever: parseInt(score(player, "clever")**2+100)
    }
    
    const progress = {
        strong: `§r${score(player, "strong_point")}/§b${requires.strong}§r`,
        speed: `§r${score(player, "speed_point")}/§b${requires.speed}§r`,
        clever: `§r${score(player, "clever_point")}/§b${requires.clever}§r`
    }
    
    const max = {
        strong: `${score(player, "strong") >=5 ? "§r§gMax§r" : "§r"}`,
        speed: `${score(player, "speed") >=3 ? "§r§gMax§r" : "§r"}`,
        clever: `${score(player, "clever") >=6 ? "§r§gMax§r" : "§r"}`,
        healthy: `${score(player, "healthy") >=20 ? "§r§gMax§r" : "§r"}`,
        life_level: `${score(player, "life_level") >=3 ? "§r§gMax§r" : "§r"}`
    }
    
    let bodyText = `
气力§r: §bLv.§r${level_color("strong", player)}${points.strong}§r ${progress.strong} ${max.strong}
敏捷§r: §bLv.§r${level_color("speed", player)}${points.speed}§r ${progress.speed} ${max.speed}
巧思§r: §bLv.§r${level_color("clever", player)}${points.clever}§r ${progress.clever} ${max.clever}
生命§r: §bLv.§r${level_color("healthy", player)}${points.healthy}§r ${max.healthy}
精神§r: §bLv.§r${level_color("life_level", player)}${points.life_level}§r ${max.life_level}
    `
    let ui = new ActionFormData()
        .title("属性面板")
        .body(bodyText)
        .button("属性介绍")
        .button("属性设置")
        .button("关闭")
        .show(player)
        .then(event => {
            switch (event.selection) {
                case 0:
                    pointsLore(player)
                    break;
                case 1:
                    pointSetting(player)
                    break;
            }
        })
};

function pointSetting(player) {
    let no_use_speed = player.hasTag("no_use_speed") ? true : false
    let ui = new ModalFormData()
        .title({ translate: "ui.setting" })
        .toggle({ translate: "ui.no_use_speed" }, no_use_speed)
        .show(player)
        .then(event => {
        if (event.formValues[0]) {
            player.addTag("no_use_speed")
        } else {
            player.removeTag("no_use_speed")
        }
    })
};

function pointsLore(player) {
    const bodyText = `
§b「属性数值」§r
气力: 每一级提供5%%物理攻击增伤
敏捷: 每一级提供一层速度效果(20%%移速加成)
巧思: 解锁格斗技巧
生命: 每一级提供1颗心
精神: 每一级减少一刻精神力恢复所需时间并提供
5%%替身增伤(不包含召唤物),每一级提供给召唤物不同效果,III级提供给召唤物1层力量,1层速度,1层抗性
§b「提升属性」§r
气力: 挖掘方块及物理攻击生物一定次数后提升
敏捷: 奔跑或跳跃一定时间后提升
巧思: 使用科普漫画提升
生命: 当气力,敏捷提升至一定程度后提升
精神: 当气力,敏捷与巧思提升至一定程度后提升
    `
    let ui = new ActionFormData()
        .title("生存战斗指南")
        .body(bodyText)
        .button("关闭")
        .show(player)
}

//-----------------------------------------------------
//函数
//________________________________________________________________

export function level_color(color, player) {
    if (score(player, color) == 0) {
        return "§7";
    }
    if (score(player, color) >= 5) {
        return "";
    }
    if (score(player, color) < 5) {
        return "";
    }
}

export function romeN(number) {
    if (number != 0 && number < 6) {
        const romeN = [
            "I", "II", "III", "IV", "V"
        ];
        return romeN[(number-1)]
    } else {
        return number;
    }
}