//-----------------------------------------------------
//导入
//________________________________________________________________

import { world, system } from '@minecraft/server';
import { ActionFormData, MessageFormData, ModalFormData } from '@minecraft/server-ui';
import { score, set } from 'score.js';
import * as lang from 'lang.js'
import { events, haveEvent } from 'events/events.js';
import { mainGb } from 'enhancement/gb'
import { fsActionForm } from 'enhancement/dna'

//-----------------------------------------------------
//变量
//________________________________________________________________

const cbb = "咕咕咕咕咕咕咕";
const version = "1.6.4.5";

//-----------------------------------------------------
//事件
//________________________________________________________________

world.afterEvents.itemUse.subscribe(event => {
    const item = event.itemStack;
    const player = event.source;
    if (item.typeId == "stand:setting") {
        main(player, [])
    }
});

world.beforeEvents.chatSend.subscribe(event => {
    const message = event.message;
    const player = event.sender;
    if (message == ".reset") {
        system.runTimeout(() => {
            reset(player)
        }, 1)
        event.cancel = true
    }
});

//-----------------------------------------------------
//菜单
//________________________________________________________________

function main(player, run) {
    const bodyText = `§7聊天栏输入.reset可重置\nMade By Johnny3150\nversion ${version}\nFind me on Bilibili: 甜美可口土豆尼\n§r建议使用经典UI游玩此addon\n§r当前事件: ${haveEvent("zombie_moon")?"§9尸鬼月":"无"}`
    let ui = new ActionFormData()
        .title({ translate: "ui.menu" })
        .body(bodyText)
        .button({ translate: "ui.stand.history" }, "textures/ui/inventory")
        .button({ translate: "ui.skill.history" }, "textures/ui/inventory")
        .button({ translate: "ui.event.history" }, "textures/ui/inventory")
        .button({ translate: "ui.gb" }, "textures/items/gb")
        if (player.hasTag("FTD")) {
            ui.button({ translate: "ui.dna" }, "textures/items/dna")
        }
        ui.button({ translate: "ui.setting" }, "textures/ui/settings_glyph_2x")
        .button((score(player, "reset_cd") > 0 ? { translate: "ui.reset.cd" } : { translate: "ui.reset" }), "textures/ui/refresh_light")
        .button({ translate: "ui.op" }, "textures/ui/tab_admin")
        .show(player)
        .then(event => {
        if (player.hasTag("FTD")) {
            switch (event.selection) {
                case 0:
                    hi(player)
                    break;
                case 1:
                    skill_hi(player)
                    break;
                case 2:
                    event_hi(player)
                    break;
                case 3:
                    mainGb(player)
                    break;
                case 4:
                    fsActionForm(player)
                    break;
                case 5:
                    setting(player)
                    break;
                case 6:
                    if (score(player, "reset_cd") == 0) {
                        reset(player)
                    }
                    break;
                case 7:
                    if (player.hasTag("创造模式")) {
                        op(player)
                    } else {
                        player.runCommand(`tellraw @s {"rawtext":[{"translate":"ui.op.no"}]}`)
                    }
                    break;
            }
        } else {
            switch (event.selection) {
                case 0:
                    hi(player)
                    break;
                case 1:
                    skill_hi(player)
                    break;
                case 2:
                    event_hi(player)
                    break;
                case 3:
                    mainGb(player)
                    break;
                case 4:
                    setting(player)
                    break;
                case 5:
                    if (score(player, "reset_cd") == 0) {
                        reset(player)
                    }
                    break;
                case 6:
                    if (player.hasTag("创造模式")) {
                        op(player)
                    } else {
                        player.runCommand(`tellraw @s {"rawtext":[{"translate":"ui.op.no"}]}`)
                    }
                    break;
            }
        }
    }).catch(() =>{
        if (run != []) {
            system.clearRun(run)
        }
    })
};

function setting(player) {
    let crosshair = score(player, "crosshair")
    let auxDamage = score(player, "aux_damage")
    let offset_x = score(player, "offset_x")
    let offset_z = score(player, "offset_z")
    let r = score(player, "tr")
    let g = score(player, "tg")
    let b = score(player, "tb")
    let a = score(player, "ta")
    let combo = player.hasTag("combo_title") ? true : false
    let jojogo = player.hasTag("jojogo") ? true : false
    let xuhua = score(player, "xuhua")
    let destroy = player.hasTag("destroy") ? true : false
    let ui = new ModalFormData()
        .title({ translate: "ui.setting" })
        .toggle({ translate: "ui.cross" }, (crosshair > 0 ? true : false))
        .toggle("辅助攻击\n开启后长按屏幕触发技能", (auxDamage > 0 ? true : false))
        .slider({ translate: "ui.offset.x" }, -50, 50, 1, offset_x)
        .slider({ translate: "ui.offset.z" }, -50, 50, 1, offset_z)
        .toggle({ translate: "ui.combo" }, combo)
        .toggle({ translate: "ui.jojogo" }, jojogo)
        .toggle({ translate: "ui.xuhua" }, (xuhua > 0 ? true : false))
        .slider({ translate: "ui.r" }, 0, 256, 1, r)
        .slider({ translate: "ui.g" }, 0, 256, 1, g)
        .slider({ translate: "ui.b" }, 0, 256, 1, b)
        .slider({ translate: "ui.a" }, 0, 100, 1, a)
        .toggle("替身破坏方块§7[个人]§r\n§7如果世界未打开替身破坏方块,个人替身无法破坏方块", destroy)
        .show(player)
        .then(event => {
        if (event.formValues[0]) {
            set(player, "crosshair", 1)
        } else {
            set(player, "crosshair", 0)
        }
        if (event.formValues[1]) {
            set(player, "aux_damage", 1)
        } else {
            set(player, "aux_damage", 0)
        }
        set(player, "offset_x", event.formValues[2])
        set(player, "offset_z", event.formValues[3])
        if (event.formValues[4]) {
            player.addTag("combo_title")
        } else {
            player.removeTag("combo_title")
        }
        if (event.formValues[5]) {
            player.addTag("jojogo")
        } else {
            player.removeTag("jojogo")
        }
        if (event.formValues[6]) {
            set(player, "xuhua", 1)
        } else {
            set(player, "xuhua", 0)
        }
        set(player, "tr", event.formValues[7])
        set(player, "tg", event.formValues[8])
        set(player, "tb", event.formValues[9])
        set(player, "ta", event.formValues[10])
        if (event.formValues[11]) {
            player.addTag("destroy")
        } else {
            player.removeTag("destroy")
        }
    })
};

function op(player) {
    let energy = player.hasTag("energy8") ? true : false
    let level = player.hasTag("level8") ? true : false
    let break_ = world.getDynamicProperty("break") == "yes" ? true : false
    let event_open = world.getDynamicProperty("event_open") == "yes" ? true : false
    let ui = new ModalFormData()
        .title({ translate: "ui.setting" })
        .toggle({ translate: "ui.energy8" }, energy)
        .toggle({ translate: "ui.level8" }, level)
        .toggle({ translate: "ui.break" }, break_)
        .toggle({ translate: "ui.event_open" }, event_open)
        .show(player)
        .then(event => {
        if (event.formValues[0]) {
            player.addTag("energy8")
        } else {
            player.removeTag("energy8")
        }
        if (event.formValues[1]) {
            player.addTag("level8")
        } else {
            player.removeTag("level8")
        }
        if (event.formValues[2]) {
            world.setDynamicProperty("break", "yes")
        } else {
            world.setDynamicProperty("break", "no")
        }
        if (event.formValues[3]) {
            world.setDynamicProperty("event_open", "yes")
        } else {
            world.setDynamicProperty("event_open", "no")
        }
    })
};

function reset(player) {
    player.runCommand("particle stand:reset ~~1~")
    player.runCommand("playsound random.levelup @a ~~~ 100 0.8 0")
    player.runCommand(`tellraw @s {"rawtext":[{"translate":"ui.reset.ok"}]}`)
    player.runCommand("scoreboard players set @s reset_cd 200")
    player.runCommand("function PlayerScoreInitialize")
    player.runCommand("function WorldScoreInitialize")
    for (var num = 0; num < 35; num++) {
        const container = player.getComponent("minecraft:inventory").container;
        player.runCommand(`replaceitem entity @s slot.inventory ${num} keep air`)
    }
};

function skill_hi(player) {
    let hi = new ActionFormData()
        .title({ translate: "ui.history" })
        .body({ translate: "ui.choose.skill.cb" })
        .button({ translate: "ui.skill.summon" }, "textures/items/egg_npc")
        .button({ translate: "ui.skill.use_skill" }, "textures/items/nether_star")
        .button({ translate: "ui.skill.mp" }, "textures/items/apple_golden")
        .button({ translate: "ui.skill.shield" }, "textures/items/empty_armor_slot_shield")
        .button({ translate: "ui.skill.barrage" }, "textures/items/crossbow_arrow")
        .button({ translate: "ui.skill.form" }, "textures/items/bone")
        .button({ translate: "ui.leave" }, "")
        .button({ translate: "ui.return" }, "")
        .show(player).then(event => {
        switch (event.selection) {
            case 0:
                skillActionForm(player,lang.skill.summon)
                break;
            case 1:
                skillActionForm(player,lang.skill.use_skill)
                break;
            case 2:
                skillActionForm(player,lang.skill.mp)
                break;
            case 3:
                skillActionForm(player,lang.skill.shield)
                break;
            case 4:
                skillActionForm(player,lang.skill.barrage)
                break;
            case 5:
                skillActionForm(player,lang.skill.form)
                break;
        }
        if (event.selection == 7) {
            main(player, [])
        }
    })
}

function event_hi(player) {
    let hi = new ActionFormData()
        .title({ translate: "ui.history" })
        .body({ translate: "ui.event.choose" })
        .button({ translate: "ui.event.zombie_moon" }, "textures/items/pluck_sword")
        .button({ translate: "ui.leave" }, "")
        .button({ translate: "ui.return" }, "")
        .show(player).then(event => {
        switch (event.selection) {
            case 0:
                eventActionForm(player,lang.zombie_moon)
                break;
        }
        if (event.selection == 2) {
            main(player, [])
        }
    })
}

function skillActionForm(player ,body) {
    let ui = new ActionFormData()
        .title({ translate: "ui.history" })
        .body(`${body}`)
        .button({ translate: "ui.leave" }, "")
        .button({ translate: "ui.return" } ,"")
        .show(player).then(event => {
        if (event.selection == 1) {
            skill_hi(player)
        }
    })
}

function standActionForm(player, body) {
    let ui = new ActionFormData()
        .title({ translate: "ui.history" })
        .body(`${body}`)
        .button({ translate: "ui.leave" }, "")
        .button({ translate: "ui.return" } ,"")
        .show(player).then(event => {
        if (event.selection == 1) {
            hi(player)
        }
    })
}

function eventActionForm(player, body) {
    let ui = new ActionFormData()
        .title({ translate: "ui.history" })
        .body(`${body}`)
        .button({ translate: "ui.leave" }, "")
        .button({ translate: "ui.return" } ,"")
        .show(player).then(event => {
        if (event.selection == 1) {
            event_hi(player)
        }
    })
}

function hi(player) {
    let hi = new ActionFormData()
        .title({ translate: "ui.history" })
        .body({ translate: "ui.choose.stand.cb2" })
        .button("「Star Platinum §eThe World」", "textures/ui/stand/sptw")
        .button("§h「Killer Queen」", "textures/ui/stand/kq")
        .button("§a「Echoes Act3」", "textures/ui/stand/e3")
        .button("§b「Crazy Diamond」", "textures/ui/stand/cd")
        .button("§5「Enigma」", "textures/ui/stand/e")
        .button("§g「Chilly Pepper」", "textures/ui/stand/cp")
        .button("§b「High Way Star」", "textures/ui/stand/hw")
        .button("§a「Bad Company」", "textures/ui/stand/bc")
        .button("§e「The Word」", "textures/ui/stand/tw")
        .button("§d「Anubis」", "textures/items/anbss")
        .button({ translate: "ui.leave" }, "")
        .button({ translate: "ui.return" }, "")
        .show(player).then(event => {
        switch (event.selection) {
            case 0:
                standActionForm(player,lang.sptwBodyText)
                break;
            case 1:
                standActionForm(player,lang.kqBodyText)
                break;
            case 2:
                standActionForm(player,lang.e3BodyText)
                break;
            case 3:
                standActionForm(player,lang.cdBodyText)
                break;
            case 4:
                standActionForm(player,lang.eBodyText)
                break;
            case 5:
                standActionForm(player,lang.cpBodyText)
                break;
            case 6:
                standActionForm(player,lang.hwBodyText)
                break;
            case 7:
                standActionForm(player,lang.bcBodyText)
                break;
            case 8:
                standActionForm(player,lang.twBodyText)
                break;
            case 9:
                standActionForm(player,lang.anbsBodyText)
                break;
        }
        if (event.selection == 11) {
            main(player, [])
        }
    })
};