//-----------------------------------------------------
//导入
//________________________________________________________________

import { ItemStack, world, system } from '@minecraft/server';
import { score, set } from 'score.js';
import { events, haveEvent } from 'events/events.js';
import { attack, projectile,  getEntites, breakBlock } from 'base/attack.js';

//-----------------------------------------------------
//事件
//________________________________________________________________

world.afterEvents.entityDie.subscribe((event) => {
    const entity = event.deadEntity;
    try {
        if (entity.hasTag("luck_zombie") && randomNum(1, 10) <= 3) {
            let newItem = new ItemStack("stand:pluck_sword", 1)
            entity.dimension.spawnItem(newItem, entity.location)
        }
        if (entity.hasTag("dio") && randomNum(1, 10) <= 5) {
            let newItem = new ItemStack("stand:dio_sword", 1)
            entity.dimension.spawnItem(newItem, entity.location)
        }
    } catch(error) {}
});

world.afterEvents.entitySpawn.subscribe(event => {
    try {
        const entity = event.entity;
        if (entity.typeId == "minecraft:zombie" && haveEvent("zombie_moon")) {
            const p = randomNum(0, 100)
            if (p <= 7) {
                entity.runCommand("replaceitem entity @s slot.armor.head 0 stand:stone_mask 1 0")
                entity.runCommand("replaceitem entity @s slot.weapon.mainhand 0 stand:dio_sword 1 0")
                entity.addTag("dio")
            }
            if (p > 7 && p <= 13) {
                entity.runCommand("replaceitem entity @s slot.armor.head 1 netherite_helmet")
                entity.runCommand("replaceitem entity @s slot.armor.chest 0 netherite_chestplate")
                entity.runCommand("replaceitem entity @s slot.weapon.mainhand 0 stand:pluck_sword 1 0")
                entity.addTag("luck_zombie")
            }
            if (p > 13 && p <= 17) {
                entity.runCommand("summon stand:zombie_shooter ~~~")
                entity.runCommand("summon stand:zombie_shooter ~~~")
                entity.runCommand("summon stand:zombie_shooter ~~~")
                entity.remove()
            }
            if (p > 17 && p <= 24) {
                entity.runCommand("replaceitem entity @s slot.armor.head 0 leather_helmet")
                entity.runCommand("replaceitem entity @s slot.armor.head 0 leather_boots")
                entity.runCommand("replaceitem entity @s slot.weapon.mainhand 0 iron_sword")
                entity.runCommand("summon zombie_horse ~~~ ~ ~ minecraft:ageable_grow_up")
                entity.runCommand("ride @s start_riding @e[type=minecraft:zombie_horse,r=3,c=1] teleport_ride")
            }
        }
    } catch (error) {
        // world.sendMessage(`${error}`)
    }
})

world.afterEvents.entityHurt.subscribe(event => {
    try {
        const entity = event.hurtEntity;
        const damagingEntity = event.damageSource.damagingEntity
        const cause = event.damageSource.cause;
        if (damagingEntity.hasTag("be_stopped_of_time"))return;
        if ((damagingEntity.getComponent("minecraft:type_family")?.hasTypeFamily("zombie") || damagingEntity.typeId == "minecraft:zombie") && cause == "entityAttack") {
            system.runTimeout(() => {
                if (!entity.hasTag("defend:true")) {
                    entity.runCommand(`particle stand:blood_cloud ~~1.25~`)
                    if (damagingEntity.typeId == "minecraft:zombie" || damagingEntity.typeId == "minecraft:husk" || damagingEntity.typeId == "minecraft:drowned") {
                        damagingEntity.runCommand(`effect @s instant_damage 1 0 true`)
                    } else {
                        damagingEntity.runCommand(`effect @s instant_health 1 0 true`)
                    }
                    damagingEntity.runCommand(`effect @s strength 20 0 true`)
                    damagingEntity.runCommand(`effect @s speed 20 0 true`)
                    damagingEntity.runCommand(`playsound random.drink @a ~~~ 20 1 0`)
                }
            }, 0.01)
        }
    } catch (error) {}
})

world.afterEvents.entityHurt.subscribe(event => {
    try {
        const entity = event.hurtEntity;
        const cause = event.damageSource.cause;
        if (entity.hasTag("be_stopped_of_time"))return;
        if ((entity.getComponent("minecraft:type_family")?.hasTypeFamily("zombie") || entity.typeId == "minecraft:zombie") && (cause == "fireTick" || cause == "fire")) {
             entity.runCommand("damage @s 5 fire_tick")
        }
    } catch (error) {}
})

//-----------------------------------------------------
//函数
//________________________________________________________________

//取随机整数
function randomNum(minNum, maxNum) {
    switch (arguments.length) {
        case 1:
            return parseInt(Math.random() * minNum + 1, 10);
            break;
        case 2:
            return parseInt(Math.random() * (maxNum - minNum + 1) + minNum, 10);
            break;
        default:
            return 0;
            break;
    }
};