// ================= 压缩函数 =================
export function compress(str) {
  const bytes = [];
  // 将字符串转为 UTF-16 字节数组
  for (let i = 0; i < str.length; i++) {
    const code = str.charCodeAt(i);
    bytes.push(code >>> 8, code & 0xFF); // 拆分为高8位和低8位
  }

  // 合并两个字节为一个 Unicode 字符
  let compressed = '';
  for (let i = 0; i < bytes.length; i += 2) {
    const byte1 = bytes[i] || 0;
    const byte2 = bytes[i + 1] || 0; // 自动补零
    compressed += String.fromCharCode((byte1 << 8) | byte2);
  }
  return compressed;
}

// ================= 解压函数 =================
export function decompress(compressed) {
  const bytes = [];
  // 拆分每个 Unicode 字符为两个字节
  for (const char of compressed) {
    const code = char.charCodeAt(0);
    bytes.push((code & 0xFF00) >>> 8, code & 0xFF);
  }

  // 移除末尾补零（如果原始字节数为奇数）
  if (bytes.length % 2 === 0 && bytes[bytes.length - 1] === 0) {
    bytes.pop();
  }

  // 将字节数组还原为字符串
  let str = '';
  for (let i = 0; i < bytes.length; i += 2) {
    const high = bytes[i];
    const low = bytes[i + 1] || 0;
    str += String.fromCharCode((high << 8) | low);
  }
  return str;
}
