//-----------------------------------------------------
//导入
//________________________________________________________________

import { ItemStack, world, system } from '@minecraft/server';
import {  ActionFormData,  MessageFormData, ModalFormData } from '@minecraft/server-ui';
import { score, set } from 'score.js';
import { level_color, romeN } from './gb.js';

//-----------------------------------------------------
//变量
//________________________________________________________________

//不同等级格斗技巧的费用

//ui
const title = "§b格斗技巧"
const body = `“§7一个人最多学习三个格斗技巧”\n§7重置格斗技巧后需重新解锁`
const results = [
    `playerResetFs(player)`,
    `showFs(player, 0)`,
    `showFs(player, 1)`,
    `showFs(player, 2)`,
    `showFs(player, 3)`,
    `showFs(player, 4)`,
    `showFs(player, 5)`,
    `showFs(player, 6)`,
    `showFs(player, 7)`,
    `showFs(player, 8)`,
    ]
    
const fs_data = [
    [
        "斩首",
        "可直接击杀血量小于15%%的目标",
        [
            4, //气力 5
            0, //敏捷 3
            2, //巧思 6
            0, //生命 10
            0 //精神 3
        ]
    ],
    [
        "恢复",
        "精神力恢复速度提升一倍",
        [
            0, //气力 5
            0, //敏捷 3
            0, //巧思 6
            0, //生命 10
            2 //精神 3
        ]
    ],
    [
        "突刺",
        "一段连击中的第一次攻击造成两倍伤害",
        [
            3, //气力 5
            1, //敏捷 3
            3, //巧思 6
            0, //生命 10
            0 //精神 3
        ]
    ],
    [
        "闪避",
        "有10%%的概率使一次非致命攻击无效化",
        [
            0, //气力 5
            3, //敏捷 3
            3, //巧思 6
            0, //生命 10
            0 //精神 3
        ]
    ],
    [
        "坚盾",
        "格挡反应时间延长50%%",
        [
            3, //气力 5
            3, //敏捷 3
            3, //巧思 6
            0, //生命 10
            0 //精神 3
        ]
    ],
    [
        "破冰",
        "对带有缓慢效果的实体造成额外50%%的伤害",
        [
            2, //气力 5
            3, //敏捷 3
            3, //巧思 6
            0, //生命 10
            0 //精神 3
        ]
    ],
    [
        "背击",
        "对背对自己的实体造成额外50%%的伤害",
        [
            3, //气力 5
            3, //敏捷 3
            4, //巧思 6
            0, //生命 10
            0 //精神 3
        ]
    ]
]

//-----------------------------------------------------
//事件
//________________________________________________________________

world.afterEvents.itemUse.subscribe(event => {
    const item = event.itemStack;
    const player = event.source;
    if (item.typeId == "stand:dna") {
        playerFsInitialize(player)
        fsActionForm(player)
        if (!player.hasTag("FTD")) {
            player.sendMessage("§7已可以通过手机打开'格斗技巧'页面")
            player.addTag("FTD")
        }
    }
});

//-----------------------------------------------------
//函数
//________________________________________________________________

/**
 * 判断玩家是否在实体背后
 * @param {Entity} player - 玩家实体
 * @param {Entity} entity - 目标实体
 * @returns {boolean} - 如果玩家在实体背后，返回 true；否则返回 false
 */
export function isPlayerBehindEntity(player, entity) {
    // 获取玩家和实体的位置
    const playerPosition = player.location;
    const entityPosition = entity.location;

    // 获取实体的朝向（Y轴旋转角度）
    const entityRotation = entity.getRotation().y;

    // 计算实体朝向的方向向量
    const entityDirection = {
        x: -Math.sin(entityRotation * (Math.PI / 180)), // 将角度转换为弧度
        z: Math.cos(entityRotation * (Math.PI / 180))
    };

    // 计算玩家相对于实体的方向向量
    const relativeDirection = {
        x: playerPosition.x - entityPosition.x,
        z: playerPosition.z - entityPosition.z
    };

    // 计算点积来判断玩家是否在实体背后
    const dotProduct = relativeDirection.x * entityDirection.x + relativeDirection.z * entityDirection.z;

    // 如果点积小于0，说明玩家在实体背后
    return dotProduct < 0;
}

function showFs(player, id) {
    const fs_results = [
        `
            const fs = new fightSkill(player);
            if (!fs.getFightSkill()["fs"][2]) {
                if (
                         score(player, "strong") >= ${fs_data[id][2][0]}
                     && score(player, "speed") >= ${fs_data[id][2][1]}
                     && score(player, "clever") >= ${fs_data[id][2][2]}
                     && score(player, "healthy") >= ${fs_data[id][2][3]}
                     && score(player, "life_level") >= ${fs_data[id][2][4]}
                ) {
                    playerGetFs(player, "${fs_data[id][0]}")
                } else {
                    player.sendMessage("§c解锁失败")
                }
            } else {
                player.sendMessage("§c解锁失败")
            }
        `,
        `fsActionForm(player)`
    ]
    const fs_body = 
    `
§b介绍: §r${fs_data[id][1]}

§b条件: §r
    §l气力 §r${romeN(fs_data[id][2][0])}
    §l敏捷 §r${romeN(fs_data[id][2][1])}
    §l巧思 §r${romeN(fs_data[id][2][2])}
    §l生命 §r${romeN(fs_data[id][2][3])}
    §l精神 §r${romeN(fs_data[id][2][4])}
    `
    const ui = new actionForm(
        fs_data[id][0],  
        fs_body, 
        fs_results
    )
    .addButton("解锁")
    .addButton("返回")
    .show(player)
}

export function playerGetFs(player, id) {
    const fs = new fightSkill(player);
    let fsn = fs.getFightSkill()["fs"]
    fsn.push(id)
    fs.setFightSkill({"fs": fsn})
    player.runCommand("function GetFsOrClearFs")
    player.sendMessage(`§a已解锁格斗技巧“${id}”`)
}

export function playerResetFs(player) {
    const fs = new fightSkill(player);
    if (fs.getFightSkill()["fs"][0]) {
        fs.setFightSkill({"fs":[]})
        player.runCommand("function GetFsOrClearFs2")
    } else {
        player.sendMessage("§c无法重置")
    }
}

export function playerFsInitialize(player) {
    const fs = new fightSkill(player);
    if (!fs.getFightSkill()) {
        fs.setFightSkill({
            "fs": []
        })
        return fs.getFightSkill();
    }
    if (!fs.getFightSkill()["fs"]) {
        fs.setFightSkill({
            "fs": []
        })
        return fs.getFightSkill();
    }
}

export function fsActionForm(player) {
    const fs = new fightSkill(player);
    const fsv = fs.getFightSkill();
    const ui = new actionForm(title, body, results)
        .addButton("§c重置", "textures/ui/crossout")
        .addButton(`§b斩首§r\n${fsv["fs"].indexOf("斩首") != -1?"§e已解锁":"§c未解锁"}`, "textures/items/iron_axe")
        .addButton(`§b恢复§r\n${fsv["fs"].indexOf("恢复") != -1?"§e已解锁":"§c未解锁"}`, "textures/items/apple_golden")
        .addButton(`§b突刺§r\n${fsv["fs"].indexOf("突刺") != -1?"§e已解锁":"§c未解锁"}`, "textures/items/trident")
        .addButton(`§b闪避§r\n${fsv["fs"].indexOf("闪避") != -1?"§e已解锁":"§c未解锁"}`, "textures/ui/speed_effect")
        .addButton(`§b坚盾§r\n${fsv["fs"].indexOf("坚盾") != -1?"§e已解锁":"§c未解锁"}`, "textures/items/turtle_shell_piece")
        .addButton(`§b破冰§r\n${fsv["fs"].indexOf("破冰") != -1?"§e已解锁":"§c未解锁"}`, "textures/items/bucket_powder_snow")
        .addButton(`§b背击§r\n${fsv["fs"].indexOf("背击") != -1?"§e已解锁":"§c未解锁"}`, "textures/items/ender_eye")
        .show(player)
};

//-----------------------------------------------------
//类
//_______________________________________________________________

export class fightSkill {
    constructor(player) {
        this.player = player;
    }

    getFightSkill() {
        let fightSkillValue = this.player.getDynamicProperty(`fs:${this.player.name}`);
        if (typeof(fightSkillValue) === "string") {
            return JSON.parse(fightSkillValue);
        } else {
            this.player.setDynamicProperty(`fs:${this.player.name}` ,`{"fs": []}`)
            let fightSkillValue2 = this.player.getDynamicProperty(`fs:${this.player.name}`);
            return JSON.parse(fightSkillValue2);
        }
    }

    setFightSkill(value) {
        this.player.setDynamicProperty(`fs:${this.player.name}`, JSON.stringify(value))
    }

}

class order {
    constructor(typeId, amount, data) {
        this.typeId = typeId;
        this.amount = amount;
        this.data = data;
    }

    check(player) {
    }

    buy(player) {
    }
}

class actionForm {
    constructor(title, body, results) {
        this.form = new ActionFormData();
        this.form.title(title);
        this.form.body(body);
        this.results = results;
    }

    addButton(text, icon = null) {
        this.form.button(text, icon);
        return this;
    }

    show(player) {
        this.form.show(player)
            .then(event => {
            eval(this.results[event.selection])
        })
    }
}

const as = new order("stand:meth_ingot", 32, 0);
const bs = new order("stand:meth_ingot", 16, 0);
const cs = new order("stand:meth_ingot", 8, 0);